# mypy-boto3-connect

[![PyPI - mypy-boto3-connect](https://img.shields.io/pypi/v/mypy-boto3-connect.svg?color=blue)](https://pypi.org/project/mypy-boto3-connect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-connect.svg?color=blue)](https://pypi.org/project/mypy-boto3-connect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Connect 1.11.7](https://boto3.amazonaws.com/v1/documentation/api/1.11.7/reference/services/connect.html#Connect) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 1.0.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-connect](#mypy-boto3-connect)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Connect` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-connect]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import connect
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_connect as connect

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("connect")
client: connect.ConnectClient = boto3.client("connect")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: connect.ConnectClient = session.client("connect")


# Paginators need type annotation on creation
get_metric_data_paginator: connect.GetMetricDataPaginator = client.get_paginator("get_metric_data")
list_contact_flows_paginator: connect.ListContactFlowsPaginator = client.get_paginator("list_contact_flows")
list_hours_of_operations_paginator: connect.ListHoursOfOperationsPaginator = client.get_paginator("list_hours_of_operations")
list_phone_numbers_paginator: connect.ListPhoneNumbersPaginator = client.get_paginator("list_phone_numbers")
list_queues_paginator: connect.ListQueuesPaginator = client.get_paginator("list_queues")
list_routing_profiles_paginator: connect.ListRoutingProfilesPaginator = client.get_paginator("list_routing_profiles")
list_security_profiles_paginator: connect.ListSecurityProfilesPaginator = client.get_paginator("list_security_profiles")
list_user_hierarchy_groups_paginator: connect.ListUserHierarchyGroupsPaginator = client.get_paginator("list_user_hierarchy_groups")
list_users_paginator: connect.ListUsersPaginator = client.get_paginator("list_users")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3_builder) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.